OC.L10N.register(
    "groupfolders",
    {
    "Denied (Inherited permission)" : "Odbijeno (naslijeđeno dopuštenje)",
    "Allowed (Inherited permission)" : "Dopušteno (naslijeđeno dopuštenje)",
    "Denied" : "Odbijeno",
    "Allowed" : "Dopušteno",
    "Access denied" : "Pristup odbijen",
    "Inherit permission" : "Naslijedi dopuštenje",
    "Deny" : "Spriječi",
    "Allow" : "Dopusti",
    "Group" : "Grupa",
    "Read" : "Čitaj",
    "Write" : "Piši",
    "Create" : "Stvori",
    "Delete" : "Izbriši",
    "Share" : "Dijeli",
    "You" : "Vi",
    "Remove access rule" : "Ukloni pravilo pristupa",
    "Select a user or group" : "Odaberite korisnika ili grupu",
    "Add group" : "Dodaj grupu",
    "Default" : "Zadani",
    "Unlimited" : "Neograničeno",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Jeste li sigurni da želite izbrisati „{folderName}” i sve sadržane datoteke? Ova se radnja ne može poništiti",
    "Delete \"{folderName}\"?" : "Izbrisati „{folderName}”?",
    "Folder name" : "Naziv mape",
    "Quota" : "Kvota",
    "Advanced Permissions" : "Napredna dopuštenja",
    "Previous" : "Natrag",
    "Next" : "Dalje",
    "User" : "@string/user_icon",
    "Unknown" : "Nepoznata pogreška",
    "None" : "Nema",
    "{size} used" : "Iskorišteno {size}",
    "Unset" : "Ukloni"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
